From 49ed8d6cc3f5be27883b6beeddf996974e68754a Mon Sep 17 00:00:00 2001
From: Simon Scholz <simon.scholz@iws.uni-stuttgart.de>
Date: Tue, 19 Dec 2017 15:58:18 +0100
Subject: [PATCH] [doxygen] fix doxygen in binarycoefficents

---
 .../binarycoefficients/CMakeLists.txt         |   2 +
 .../binarycoefficients/air_mesitylene.hh      |   8 +-
 .../material/binarycoefficients/air_xylene.hh |  10 +-
 .../material/binarycoefficients/brine_air.hh  | 125 +++++++++---------
 .../material/binarycoefficients/brine_co2.hh  |  10 +-
 .../binarycoefficients/fullermethod.hh        |   3 +-
 dumux/material/binarycoefficients/h2o_air.hh  |   6 +-
 .../binarycoefficients/h2o_constant.hh        |  26 ++--
 .../binarycoefficients/h2o_heavyoil.hh        |  24 ++--
 .../binarycoefficients/h2o_mesitylene.hh      |   7 +-
 dumux/material/binarycoefficients/h2o_n2.hh   |   2 +-
 dumux/material/binarycoefficients/h2o_o2.hh   |   6 +-
 .../material/binarycoefficients/h2o_xylene.hh |   4 +-
 .../material/binarycoefficients/henryiapws.hh |   3 +-
 dumux/material/binarycoefficients/n2_o2.hh    |   2 +-
 15 files changed, 116 insertions(+), 122 deletions(-)

diff --git a/dumux/material/binarycoefficients/CMakeLists.txt b/dumux/material/binarycoefficients/CMakeLists.txt
index 1dd91a40f6..488f662214 100644
--- a/dumux/material/binarycoefficients/CMakeLists.txt
+++ b/dumux/material/binarycoefficients/CMakeLists.txt
@@ -7,6 +7,8 @@ brine_air.hh
 brine_co2.hh
 fullermethod.hh
 h2o_air.hh
+h2o_constant.hh
+h2o_heavyoil.hh
 h2o_mesitylene.hh
 h2o_n2.hh
 h2o_o2.hh
diff --git a/dumux/material/binarycoefficients/air_mesitylene.hh b/dumux/material/binarycoefficients/air_mesitylene.hh
index ef1fb32aef..9c32d8f23f 100644
--- a/dumux/material/binarycoefficients/air_mesitylene.hh
+++ b/dumux/material/binarycoefficients/air_mesitylene.hh
@@ -18,7 +18,7 @@
  *****************************************************************************/
 /*!
  * \file
- *
+ * \ingroup Binarycoefficients
  * \brief Binary coefficients for air and mesitylene.
  */
 #ifndef DUMUX_BINARY_COEFF_AIR_MESITYLENE_HH
@@ -33,15 +33,15 @@ namespace BinaryCoeff
 {
 
 /*!
+ * \ingroup Binarycoefficients
  * \brief Binary coefficients for water and mesitylene.
- * \param temperature temperature in \f$\mathrm{[K]}\f$
- *
  */
 class Air_Mesitylene
 {
 public:
     /*!
-     *
+     * \brief Henry coefficient \f$\mathrm{[Pa]}\f$  for mesitylene in air.
+     * \param temperature the temperature \f$\mathrm{[K]}\f$
      */
     template <class Scalar>
     static Scalar henry(Scalar temperature)
diff --git a/dumux/material/binarycoefficients/air_xylene.hh b/dumux/material/binarycoefficients/air_xylene.hh
index 811a89fc7d..79cdae79e1 100644
--- a/dumux/material/binarycoefficients/air_xylene.hh
+++ b/dumux/material/binarycoefficients/air_xylene.hh
@@ -18,7 +18,7 @@
  *****************************************************************************/
 /*!
  * \file
- *
+ * \ingroup Binarycoefficients
  * \brief Binary coefficients for air and xylene.
  */
 #ifndef DUMUX_BINARY_COEFF_AIR_XYLENE_HH
@@ -33,15 +33,15 @@ namespace BinaryCoeff
 {
 
 /*!
- * \brief Binary coefficients for water and xylene.
- * \param temperature temperature in \f$\mathrm{[K]}\f$
- *
+ * \ingroup Binarycoefficients
+ * \brief Binary coefficients for air and xylene.
  */
 class Air_Xylene
 {
 public:
     /*!
-     *
+     * \brief Henry coefficient \f$\mathrm{[Pa]}\f$  for mesitylene in air.
+     * \param temperature the temperature \f$\mathrm{[K]}\f$
      */
     template <class Scalar>
     static Scalar henry(Scalar temperature)
diff --git a/dumux/material/binarycoefficients/brine_co2.hh b/dumux/material/binarycoefficients/brine_co2.hh
index add4d655c0..2ccd73f9e5 100644
--- a/dumux/material/binarycoefficients/brine_co2.hh
+++ b/dumux/material/binarycoefficients/brine_co2.hh
@@ -18,7 +18,6 @@
  *****************************************************************************/
 /*!
  * \file
- *
  * \ingroup Binarycoefficients
  * \brief Binary coefficients for CO2 and brine.
  */
@@ -33,6 +32,7 @@
 namespace Dumux {
 namespace BinaryCoeff {
 /*!
+ * \ingroup Binarycoefficients
  * \brief Binary coefficients for brine and CO2.
  */
 template<class Scalar, class CO2Tables, bool verbose = true>
@@ -92,7 +92,6 @@ public:
      * \param xlCO2 mole fraction of CO2 in brine \f$\mathrm{[mol/mol]}\f$
      * \param ygH2O mole fraction of water in the gas phase \f$\mathrm{[mol/mol]}\f$
      */
-
     static void calculateMoleFractions(const Scalar temperature,
                                        const Scalar pg,
                                        const Scalar salinity,
@@ -442,10 +441,10 @@ public:
 
 private:
     /*!
-    * \brief computation of \f$\mathrm{[mu_{CO2}^{l(0)}/RT]}\f$
+     * \brief computation of \f$\mathrm{[mu_{CO2}^{l(0)}/RT]}\f$
      * \param T the temperature \f$\mathrm{[K]}\f$
      * \param pg the gas phase pressure \f$\mathrm{[Pa]}\f$
-    */
+     */
     static Scalar computeA_(Scalar T, Scalar pg)
     {
         static const Scalar c[10] = {
@@ -504,6 +503,7 @@ private:
             c9*pg_bar/(630.0-T) +
             c11*T*log(pg_bar);
     }
+
     /*!
      * \brief computation of C
      *
@@ -525,6 +525,7 @@ private:
             c8*pg_bar/T +
             c9*pg_bar/(630.0-T);
     }
+
     /*!
      * \brief computation of partial pressure CO2
      *
@@ -547,7 +548,6 @@ private:
      * \param pg the gas phase pressure \f$\mathrm{[Pa]}\f$
      * \param rhoCO2 the density of CO2 for the critical volume \f$\mathrm{[kg/m^3]}\f$
      */
-
     static Scalar fugacityCoeffCO2_(Scalar temperature,
                                     Scalar pg,
                                     Scalar rhoCO2)
diff --git a/dumux/material/binarycoefficients/fullermethod.hh b/dumux/material/binarycoefficients/fullermethod.hh
index 27646cc341..222b992174 100644
--- a/dumux/material/binarycoefficients/fullermethod.hh
+++ b/dumux/material/binarycoefficients/fullermethod.hh
@@ -18,7 +18,9 @@
  *****************************************************************************/
 /*!
  * \file
+ * \ingroup Binarycoefficients
  * \brief Various relations for molecular diffusion coefficients.
+ * \copydetails fullerMethod
  */
 #ifndef DUMUX_FULLERMETHOD_HH
 #define DUMUX_FULLERMETHOD_HH
@@ -30,7 +32,6 @@ namespace Dumux
 namespace BinaryCoeff
 {
 /*!
- * \ingroup Binarycoefficients
  * \brief Estimate binary diffusion coefficients \f$\mathrm{[m^2/s]}\f$ in gases according to
  *        the method by Fuller.
  *
diff --git a/dumux/material/binarycoefficients/h2o_air.hh b/dumux/material/binarycoefficients/h2o_air.hh
index ef688f0e28..57269cda07 100644
--- a/dumux/material/binarycoefficients/h2o_air.hh
+++ b/dumux/material/binarycoefficients/h2o_air.hh
@@ -18,8 +18,8 @@
  *****************************************************************************/
 /*!
  * \file
- *
- * \brief Binary coefficients for water and nitrogen.
+ * \ingroup Binarycoefficients
+ * \brief Binary coefficients for water and air.
  */
 #ifndef DUMUX_BINARY_COEFF_H2O_AIR_HH
 #define DUMUX_BINARY_COEFF_H2O_AIR_HH
@@ -34,7 +34,7 @@ namespace BinaryCoeff
 
 /*!
  * \ingroup Binarycoefficients
- * \brief Binary coefficients for water and nitrogen.
+ * \brief Binary coefficients for water and air.
  */
 class H2O_Air
 {
diff --git a/dumux/material/binarycoefficients/h2o_constant.hh b/dumux/material/binarycoefficients/h2o_constant.hh
index b686fe5885..dd95b09d55 100644
--- a/dumux/material/binarycoefficients/h2o_constant.hh
+++ b/dumux/material/binarycoefficients/h2o_constant.hh
@@ -18,7 +18,7 @@
  *****************************************************************************/
 /*!
  * \file
- *
+ * \ingroup Binarycoefficients
  * \brief Binary coefficients for water and a "constant" component.
  */
 #ifndef DUMUX_BINARY_COEFF_H2O_CONSTANT_HH
@@ -37,6 +37,7 @@ namespace BinaryCoeff
 {
 
 /*!
+ * \ingroup Binarycoefficients
  * \brief Binary coefficients for water and another component.
  * \todo All other binary coefficient could be generalized like this
  */
@@ -58,12 +59,10 @@ class H2O_Component<Scalar, Components::Constant<id, Scalar>>
 {
 public:
     /*!
-     * \brief Henry coefficent \f$N/m^2\f$  for heavy oil in liquid water.
-     *
-     * See:
+     * \brief Henry coefficent \f$N/m^2\f$  for the constant component in liquid water.
      *
+     * \param temperature the temperature \f$\mathrm{[K]}\f$
      */
-
     static Scalar henryCompInWater(Scalar temperature)
     {
         static const Scalar h = getParamFromGroup<Scalar>(std::to_string(id), "Component.HenryComponentInWater", 1.0);
@@ -71,12 +70,10 @@ public:
     }
 
     /*!
-     * \brief Henry coefficent \f$N/m^2\f$  for water in liquid heavy oil.
-     *
-     * See:
+     * \brief Henry coefficent \f$N/m^2\f$  for water in the constant component.
      *
+     * \param temperature the temperature \f$\mathrm{[K]}\f$
      */
-
     static Scalar henryWaterInComp(Scalar temperature)
     {
         static const Scalar h = getParamFromGroup<Scalar>(std::to_string(id), "Component.HenryWaterInComponent", 1.0);
@@ -85,8 +82,9 @@ public:
 
 
     /*!
-     * \brief Binary diffusion coefficent \f$m^2/s\f$ for molecular water and heavy oil.
-     *
+     * \brief Binary diffusion coefficent \f$m^2/s\f$ for molecular water and the constant component.
+     * \param temperature the temperature \f$\mathrm{[K]}\f$
+     * \param pressure the phase pressure \f$\mathrm{[Pa]}\f$
      */
     static Scalar gasDiffCoeff(Scalar temperature, Scalar pressure)
     {
@@ -95,9 +93,9 @@ public:
     }
 
     /*!
-     * \brief Diffusion coefficent \f$m^2/s\f$ for tce in liquid water.
-     *
-     * \todo
+     * \brief Diffusion coefficent \f$m^2/s\f$ for the constant component in liquid water.
+     * \param temperature the temperature \f$\mathrm{[K]}\f$
+     * \param pressure the phase pressure \f$\mathrm{[Pa]}\f$
      */
     static Scalar liquidDiffCoeff(Scalar temperature, Scalar pressure)
     {
diff --git a/dumux/material/binarycoefficients/h2o_heavyoil.hh b/dumux/material/binarycoefficients/h2o_heavyoil.hh
index cead97c2f5..86d494be7c 100644
--- a/dumux/material/binarycoefficients/h2o_heavyoil.hh
+++ b/dumux/material/binarycoefficients/h2o_heavyoil.hh
@@ -18,8 +18,8 @@
  *****************************************************************************/
 /*!
  * \file
- *
- * \brief Binary coefficients for water and tce.
+ * \ingroup Binarycoefficients
+ * \brief Binary coefficients for water and heavy oil.
  */
 #ifndef DUMUX_BINARY_COEFF_H2O_HEAVYOIL_HH
 #define DUMUX_BINARY_COEFF_H2O_HEAVYOIL_HH
@@ -33,6 +33,7 @@ namespace BinaryCoeff
 {
 
 /*!
+ * \ingroup Binarycoefficients
  * \brief Binary coefficients for water and heavy oil as in SAGD processes
  */
 class H2O_HeavyOil
@@ -40,11 +41,8 @@ class H2O_HeavyOil
 public:
     /*!
      * \brief Henry coefficient \f$[N/m^2]\f$  for heavy oil in liquid water.
-     *
-     * See:
-     *
+     * \param temperature the temperature \f$\mathrm{[K]}\f$
      */
-
     template <class Scalar>
     static Scalar henryOilInWater(Scalar temperature)
     {
@@ -56,11 +54,8 @@ public:
 
     /*!
      * \brief Henry coefficient \f$[N/m^2]\f$  for water in liquid heavy oil.
-     *
-     * See:
-     *
+     * \param temperature the temperature \f$\mathrm{[K]}\f$
      */
-
     template <class Scalar>
     static Scalar henryWaterInOil(Scalar temperature)
     {
@@ -71,7 +66,8 @@ public:
 
     /*!
      * \brief Binary diffusion coefficient [m^2/s] for molecular water and heavy oil.
-     *
+     * \param temperature the temperature \f$\mathrm{[K]}\f$
+     * \param pressure the phase pressure \f$\mathrm{[Pa]}\f$
      */
     template <class Scalar>
     static Scalar gasDiffCoeff(Scalar temperature, Scalar pressure)
@@ -80,9 +76,9 @@ public:
     }
 
     /*!
-     * \brief Diffusion coefficient [m^2/s] for tce in liquid water.
-     *
-     * \todo
+     * \brief Diffusion coefficient [m^2/s] for heavy oil in liquid water.
+     * \param temperature the temperature \f$\mathrm{[K]}\f$
+     * \param pressure the phase pressure \f$\mathrm{[Pa]}\f$
      */
     template <class Scalar>
     static Scalar liquidDiffCoeff(Scalar temperature, Scalar pressure)
diff --git a/dumux/material/binarycoefficients/h2o_mesitylene.hh b/dumux/material/binarycoefficients/h2o_mesitylene.hh
index b19a70bcc7..747598a002 100644
--- a/dumux/material/binarycoefficients/h2o_mesitylene.hh
+++ b/dumux/material/binarycoefficients/h2o_mesitylene.hh
@@ -18,7 +18,7 @@
  *****************************************************************************/
 /*!
  * \file
- *
+ * \ingroup Binarycoefficients
  * \brief Binary coefficients for water and mesitylene.
  */
 #ifndef DUMUX_BINARY_COEFF_H2O_MESITYLENE_HH
@@ -33,6 +33,7 @@ namespace BinaryCoeff
 {
 
 /*!
+ * \ingroup Binarycoefficients
  * \brief Binary coefficients for water and mesitylene.
  */
 class H2O_Mesitylene
@@ -42,8 +43,7 @@ public:
      * \brief Henry coefficient \f$\mathrm{[Pa]}\f$  for mesitylene in liquid water.
      * \param temperature the temperature \f$\mathrm{[K]}\f$
      * See:
-     *
-     *  R. Sander (1999) \cite sander1999
+     * R. Sander (1999) \cite sander1999
      */
     template <class Scalar>
     static Scalar henry(Scalar temperature)
@@ -60,7 +60,6 @@ public:
      * \brief Binary diffusion coefficient \f$\mathrm{[m^2/s]}\f$ for molecular water and mesitylene.
      * \param temperature the temperature \f$\mathrm{[K]}\f$
      * \param pressure the pressure \f$\mathrm{[Pa]}\f$
-     *
      */
     template <class Scalar>
     static Scalar gasDiffCoeff(Scalar temperature, Scalar pressure)
diff --git a/dumux/material/binarycoefficients/h2o_n2.hh b/dumux/material/binarycoefficients/h2o_n2.hh
index b1e2128f95..17ac08e6b6 100644
--- a/dumux/material/binarycoefficients/h2o_n2.hh
+++ b/dumux/material/binarycoefficients/h2o_n2.hh
@@ -18,7 +18,7 @@
  *****************************************************************************/
 /*!
  * \file
- *
+ * \ingroup Binarycoefficients
  * \brief Binary coefficients for water and nitrogen.
  */
 #ifndef DUMUX_BINARY_COEFF_H2O_N2_HH
diff --git a/dumux/material/binarycoefficients/h2o_o2.hh b/dumux/material/binarycoefficients/h2o_o2.hh
index f5022d0f20..0602ef6a40 100644
--- a/dumux/material/binarycoefficients/h2o_o2.hh
+++ b/dumux/material/binarycoefficients/h2o_o2.hh
@@ -18,7 +18,7 @@
  *****************************************************************************/
 /*!
  * \file
- *
+ * \ingroup Binarycoefficients
  * \brief Binary coefficients for water and oxygen.
  */
 #ifndef DUMUX_BINARY_COEFF_H2O_O2_HH
@@ -58,7 +58,7 @@ public:
     }
 
     /*!
-     * \brief Binary diffusion coefficient \f$\mathrm{[m^2/s]}\f$ for molecular water and nitrogen.
+     * \brief Binary diffusion coefficient \f$\mathrm{[m^2/s]}\f$ for molecular water and oxygen.
      *
      * Uses fullerMethod to determine the diffusion of water in nitrogen.
      * \param temperature the temperature \f$\mathrm{[K]}\f$
@@ -79,7 +79,7 @@ public:
     }
 
     /*!
-     * \brief Diffusion coefficient \f$\mathrm{[m^2/s]}\f$ for molecular nitrogen in liquid water.
+     * \brief Diffusion coefficient \f$\mathrm{[m^2/s]}\f$ for molecular oxygen in liquid water.
      * \param temperature the temperature \f$\mathrm{[K]}\f$
      * \param pressure the phase pressure \f$\mathrm{[Pa]}\f$
      *
diff --git a/dumux/material/binarycoefficients/h2o_xylene.hh b/dumux/material/binarycoefficients/h2o_xylene.hh
index 4c0c135618..3ab32237d0 100644
--- a/dumux/material/binarycoefficients/h2o_xylene.hh
+++ b/dumux/material/binarycoefficients/h2o_xylene.hh
@@ -18,7 +18,7 @@
  *****************************************************************************/
 /*!
  * \file
- *
+ * \ingroup Binarycoefficients
  * \brief Binary coefficients for water and xylene.
  */
 #ifndef DUMUX_BINARY_COEFF_H2O_XYLENE_HH
@@ -33,6 +33,7 @@ namespace BinaryCoeff
 {
 
 /*!
+ * \ingroup Binarycoefficients
  * \brief Binary coefficients for water and xylene.
  */
 class H2O_Xylene
@@ -46,7 +47,6 @@ public:
      *
      *  Sander (1999) \cite sander1999
      */
-
     template <class Scalar>
     static Scalar henry(Scalar temperature)
     {
diff --git a/dumux/material/binarycoefficients/henryiapws.hh b/dumux/material/binarycoefficients/henryiapws.hh
index 7aff4c840d..855b67dc0a 100644
--- a/dumux/material/binarycoefficients/henryiapws.hh
+++ b/dumux/material/binarycoefficients/henryiapws.hh
@@ -18,7 +18,7 @@
  *****************************************************************************/
 /*!
  * \file
- *
+ * \ingroup Binarycoefficients
  * \brief The IAPWS formulation of Henry coefficients in water.
  */
 #ifndef DUMUX_HENRY_IAPWS_HH
@@ -29,7 +29,6 @@
 namespace Dumux
 {
 /*!
- * \ingroup Binarycoefficients
  * \brief The Henry constants in liquid water using the IAPWS 2004
  *        formulation.
  * \param E Correlation parameter
diff --git a/dumux/material/binarycoefficients/n2_o2.hh b/dumux/material/binarycoefficients/n2_o2.hh
index 5baae1d2d2..16216c1f73 100644
--- a/dumux/material/binarycoefficients/n2_o2.hh
+++ b/dumux/material/binarycoefficients/n2_o2.hh
@@ -18,7 +18,7 @@
  *****************************************************************************/
 /*!
  * \file
- *
+ * \ingroup Binarycoefficients
  * \brief Binary coefficients for nitrogen and oxygen.
  */
 #ifndef DUMUX_BINARY_COEFF_N2_O2_HH
diff --git a/dumux/material/binarycoefficients/brine_air.hh b/dumux/material/binarycoefficients/brine_air.hh
index 3222c8df63..600642a38a 100644
--- a/dumux/material/binarycoefficients/brine_air.hh
+++ b/dumux/material/binarycoefficients/brine_air.hh
@@ -18,9 +18,8 @@
  *****************************************************************************/
 /*!
  * \file
- *
  * \ingroup Binarycoefficients
- * \brief Binary coefficients for Air and brine.
+ * \brief Binary coefficients for Brine and Air.
  */
 #ifndef DUMUX_BINARY_COEFF_BRINE_Air_HH
 #define DUMUX_BINARY_COEFF_BRINE_Air_HH
@@ -33,7 +32,8 @@
 namespace Dumux {
 namespace BinaryCoeff {
 /*!
- * \brief Binary coefficients for brine and Air.
+ * \ingroup Binarycoefficients
+ * \brief Binary coefficients for Brine and Air.
  */
 template<class Scalar, class Air, bool verbose = true>
 class Brine_Air {
@@ -41,12 +41,12 @@ class Brine_Air {
    // using Air = Dumux::Air<Scalar>;
     using Brine = Dumux::Brine<Scalar,H2O>;
     using IdealGas = Dumux::IdealGas<Scalar>;
-    static const int lPhaseIdx = 0; // index of the liquid phase
-    static const int gPhaseIdx = 1; // index of the gas phase
+    static const int wPhaseIdx = 0; // index of the liquid phase
+    static const int nPhaseIdx = 1; // index of the gas phase
 
 public:
     /*!
-     * \brief Binary diffusion coefficient \f$\mathrm{[m^2/s]}\f$ of water in the Air phase.
+     *  \brief Binary diffusion coefficient \f$\mathrm{[m^2/s]}\f$ of water in the Air phase.
      *
      * According to B. Xu et al. (2003) \cite xu2003 <BR>
      * \param temperature the temperature \f$\mathrm{[K]}\f$
@@ -65,24 +65,24 @@ public:
     ;
 
     /*!
-        * Lacking better data on water-air diffusion in liquids, we use at the
-        * moment the diffusion coefficient of the air's main component nitrogen!!
-        * \brief Diffusion coefficient \f$\mathrm{[m^2/s]}\f$ for molecular nitrogen in liquid water.
-        *
-        * The empirical equations for estimating the diffusion coefficient in
-        * infinite solution which are presented in Reid, 1987 all show a
-        * linear dependency on temperature. We thus simply scale the
-        * experimentally obtained diffusion coefficient of Ferrell and
-        * Himmelblau by the temperature.
-        * \param temperature The temperature \f$\mathrm{[K]}\f$
-        * \param pressure The pressure \f$\mathrm{[Pa]}\f$
-        *
-        * See:
-        *
-        * R. Reid et al. (1987, pp. 599) \cite reid1987 <BR>
-        *
-        * R. Ferrell, D. Himmelblau (1967, pp. 111-115) \cite ferrell1967
-        */
+     * Lacking better data on water-air diffusion in liquids, we use at the
+     * moment the diffusion coefficient of the air's main component nitrogen!!
+     * \brief Diffusion coefficient \f$\mathrm{[m^2/s]}\f$ for molecular nitrogen in liquid water.
+     *
+     * The empirical equations for estimating the diffusion coefficient in
+     * infinite solution which are presented in Reid, 1987 all show a
+     * linear dependency on temperature. We thus simply scale the
+     * experimentally obtained diffusion coefficient of Ferrell and
+     * Himmelblau by the temperature.
+     * \param temperature The temperature \f$\mathrm{[K]}\f$
+     * \param pressure The pressure \f$\mathrm{[Pa]}\f$
+     *
+     * See:
+     *
+     * R. Reid et al. (1987, pp. 599) \cite reid1987 <BR>
+     *
+     * R. Ferrell, D. Himmelblau (1967, pp. 111-115) \cite ferrell1967
+     */
     static Scalar liquidDiffCoeff(Scalar temperature, Scalar pressure) {
         //Diffusion coefficient of Air in the H2O phase
         const Scalar Texp = 273.15 + 25; // [K]
@@ -94,7 +94,7 @@ public:
      * \brief Returns the _mol_ (!) fraction of Air in the liquid
      *        phase and the mol_ (!) fraction of H2O in the gas phase
      *        for a given temperature, pressure, Air density and brine
-     *        XlNaCl.
+     *        XwNaCl.
      *
      *        Implemented according to Spycher and Pruess (2005) \cite spycher2005 <BR>
      *        applying the activity coefficient expression of Duan and Sun (2003) \cite duan2003 <BR>
@@ -102,52 +102,52 @@ public:
      *
      * \param temperature the temperature \f$\mathrm{[K]}\f$
      * \param pg the gas phase pressure \f$\mathrm{[Pa]}\f$
      * \param XlNaCl the XlNaCl \f$\mathrm{[kg NaCl / kg solution]}\f$
      * \param knownPhaseIdx indicates which phases are present
      * \param xlAir mole fraction of Air in brine \f$\mathrm{[mol/mol]}\f$
      * \param ygH2O mole fraction of water in the gas phase \f$\mathrm{[mol/mol]}\f$
      * \param xlNaCl the xlNaCl
      */
     static void calculateMoleFractions(const Scalar temperature,
                                        const Scalar pg,
-                                       const Scalar XlNaCl,
+                                       const Scalar XwNaCl,
                                        const int knownPhaseIdx,
-                                       Scalar &xlAir,
-                                       Scalar &ygH2O,
-                                     Scalar &xlNaCl) {
+                                       Scalar &xwAir,
+                                       Scalar &xnH2O,
+                                     Scalar &xwNaCl) {
         DUNE_THROW(Dune::InvalidStateException, "Function: " << "calculateMoleFractions" << " is invalid.");
 //        Scalar A = computeA_(temperature, pg);
 //
 //        /* XlNaCl: conversion from mass fraction to mol fraction */
 //        xlNaCl = massTomoleFrac_(XlNaCl);
 //
 //        // if both phases are present the mole fractions in each phase can be calculate
 //        // with the mutual solubility function
 //        if (knownPhaseIdx < 0) {
 //            Scalar molalityNaCl = molFracToMolality_(xlNaCl); // molality of NaCl //CHANGED
 //            Scalar m0_Air = molalityAirinPureWater_(temperature, pg); // molality of Air in pure water
 //            Scalar gammaStar = activityCoefficient_(temperature, pg, molalityNaCl);// activity coefficient of Air in brine
 //            Scalar m_Air = m0_Air / gammaStar; // molality of Air in brine
-//            xlAir = m_Air / (molalityNaCl + 55.508 + m_Air); // mole fraction of Air in brine
-//            ygH2O = A * (1 - xlAir - xlNaCl); // mole fraction of water in the gas phase
+//            xwAir = m_Air / (molalityNaCl + 55.508 + m_Air); // mole fraction of Air in brine
+//            xnH2O = A * (1 - xwAir - xwNaCl); // mole fraction of water in the gas phase
 //        }
 //
 //        // if only liquid phase is present the mole fraction of Air in brine is given and
 //        // and the virtual equilibrium mole fraction of water in the non-existing gas phase can be estimated
 //        // with the mutual solubility function
-//        if (knownPhaseIdx == lPhaseIdx) {
-////            ygH2O = A * (1 - xlAir - xlNaCl);
-//          DUNE_THROW(Dune::InvalidStateException, "phase index: " << "lPhaseIdx" << " is invalid.");
+//        if (knownPhaseIdx == wPhaseIdx) {
+////            xnH2O = A * (1 - xwAir - xwNaCl);
+//          DUNE_THROW(Dune::InvalidStateException, "phase index: " << "wPhaseIdx" << " is invalid.");
 //
 //        }
 //
 //        // if only gas phase is present the mole fraction of water in the gas phase is given and
 //        // and the virtual equilibrium mole fraction of Air in the non-existing liquid phase can be estimated
 //        // with the mutual solubility function
-//        if (knownPhaseIdx == gPhaseIdx) {
+//        if (knownPhaseIdx == nPhaseIdx) {
 //            //y_H2o = fluidstate.
-////            xlAir = 1 - xlNaCl - ygH2O / A;
-//          DUNE_THROW(Dune::InvalidStateException, "phase index: " << "gPhaseIdx" << " is invalid.");
+////            xwAir = 1 - xwNaCl - xnH2O / A;
+//          DUNE_THROW(Dune::InvalidStateException, "phase index: " << "nPhaseIdx" << " is invalid.");
 //        }
     }
 
@@ -212,12 +212,12 @@ public:
     /*!
      * \brief Returns the molality of NaCl \f$\mathrm{(mol NaCl / kg water)}\f$ for a given mole fraction \f$\mathrm{(mol NaCl / mol solution)}\f$
      *
      * \param XlNaCl mole fraction of NaCL in brine \f$\mathrm{[mol/mol]}\f$
      */
-    static Scalar molalityNaCl(Scalar XlNaCl) {
+    static Scalar molalityNaCl(Scalar XwNaCl) {
 
         // conversion from mol fraction to molality
-        const Scalar mol_NaCl = XlNaCl / 58.4428e-3;
+        const Scalar mol_NaCl = XwNaCl / 58.4428e-3;
 
         return mol_NaCl;
     }
@@ -226,19 +226,19 @@ private:
     /*!
      * \brief Returns the molality of NaCl \f$\mathrm{(mol NaCl / kg water)}\f$ for a given mole fraction
      *
      * \param XlNaCl the XlNaCl \f$\mathrm{[kg NaCl / kg solution]}\f$
      */
-    static Scalar massTomoleFrac_(Scalar XlNaCl) {
+    static Scalar massTomoleFrac_(Scalar XwNaCl) {
 
         DUNE_THROW(Dune::InvalidStateException, "Function: " << "massTomoleFrac_" << " is invalid.");
 
 //        const Scalar Mw = H2O::molarMass(); /* molecular weight of water [kg/mol] */
 //        const Scalar Ms = 58.8e-3; /* molecular weight of NaCl  [kg/mol] */
 //
 //        const Scalar X_NaCl = XlNaCl;
 //        /* XlNaCl: conversion from mass fraction to mol fraction */
 //        const Scalar xlNaCl = -Mw * X_NaCl / ((Ms - Mw) * X_NaCl - Ms);
 //        return xlNaCl;
     }
 
     /*!
@@ -431,12 +431,12 @@ public:
         const Scalar Mw = H2O::molarMass(); /* molecular weight of water [kg/mol] */
         const Scalar Ms = 58.8e-3; /* molecular weight of NaCl  [kg/mol] */
 
-        const Scalar X_NaCl = Brine::XlNaCl;
-        /* XlNaCl: conversion from mass fraction to mole fraction */
-        const Scalar xlNaCl = -Mw * X_NaCl / ((Ms - Mw) * X_NaCl - Ms);
+        const Scalar X_NaCl = Brine::XwNaCl;
+        /* XwNaCl: conversion from mass fraction to mole fraction */
+        const Scalar xwNaCl = -Mw * X_NaCl / ((Ms - Mw) * X_NaCl - Ms);
 
-        // XlNaCl: conversion from mole fraction to molality
-        const Scalar mol_NaCl = -55.56 * xlNaCl / (xlNaCl - 1);
+        // XwNaCl: conversion from mole fraction to molality
+        const Scalar mol_NaCl = -55.56 * xwNaCl / (xwNaCl - 1);
 
         const Scalar A = computeA_(temperature, pg); /* mu_{Air}^{l(0)}/RT */
         const Scalar B = computeB_(temperature, pg); /* lambda_{Air-Na+} */
@@ -459,10 +459,10 @@ public:
 
 private:
     /*!
-    * \brief computation of mu_{Air}^{l(0)}/RT
-    * \param T the temperature [K]
-    * \param pg the gas phase pressure [Pa]
-    */
+     * \brief computation of mu_{Air}^{l(0)}/RT
+     * \param T the temperature [K]
+     * \param pg the gas phase pressure [Pa]
+     */
     static Scalar computeA_(Scalar T, Scalar pg)
     {
         static const Scalar c[10] = {
@@ -564,7 +564,6 @@ private:
      * \param pg the gas phase pressure [Pa]
      * \param rhoAir the density of Air for the critical volume [kg/m^3]
      */
-
     static Scalar fugacityCoeffAir_(Scalar temperature,
                                     Scalar pg,
                                     Scalar rhoAir)
@@ -102,52 +102,52 @@ public:
      * \param temperature the temperature \f$\mathrm{[K]}\f$
      * \param pg the gas phase pressure \f$\mathrm{[Pa]}\f$
-     * \param XlNaCl the XlNaCl \f$\mathrm{[kg NaCl / kg solution]}\f$
+     * \param XwNaCl the XwNaCl \f$\mathrm{[kg NaCl / kg solution]}\f$
      * \param knownPhaseIdx indicates which phases are present
@@ -102,52 +102,52 @@ public:
      * \param knownPhaseIdx indicates which phases are present
-     * \param xlAir mole fraction of Air in brine \f$\mathrm{[mol/mol]}\f$
-     * \param ygH2O mole fraction of water in the gas phase \f$\mathrm{[mol/mol]}\f$
-     * \param xlNaCl the xlNaCl
+     * \param xwAir mole fraction of Air in brine \f$\mathrm{[mol/mol]}\f$
+     * \param xnH2O mole fraction of water in the gas phase \f$\mathrm{[mol/mol]}\f$
+     * \param xwNaCl the xwNaCl
      */
     static void calculateMoleFractions(const Scalar temperature,
@@ -102,52 +102,52 @@ public:
 //        Scalar A = computeA_(temperature, pg);
 //
-//        /* XlNaCl: conversion from mass fraction to mol fraction */
-//        xlNaCl = massTomoleFrac_(XlNaCl);
+//        /* XwNaCl: conversion from mass fraction to mol fraction */
+//        xwNaCl = massTomoleFrac_(XwNaCl);
 //
 //        // if both phases are present the mole fractions in each phase can be calculate
@@ -102,52 +102,52 @@ public:
 //        // with the mutual solubility function
 //        if (knownPhaseIdx < 0) {
-//            Scalar molalityNaCl = molFracToMolality_(xlNaCl); // molality of NaCl //CHANGED
+//            Scalar molalityNaCl = molFracToMolality_(xwNaCl); // molality of NaCl //CHANGED
 //            Scalar m0_Air = molalityAirinPureWater_(temperature, pg); // molality of Air in pure water
 //            Scalar gammaStar = activityCoefficient_(temperature, pg, molalityNaCl);// activity coefficient of Air in brine
@@ -212,12 +212,12 @@ public:
      * \brief Returns the molality of NaCl \f$\mathrm{(mol NaCl / kg water)}\f$ for a given mole fraction \f$\mathrm{(mol NaCl / mol solution)}\f$
      *
-     * \param XlNaCl mole fraction of NaCL in brine \f$\mathrm{[mol/mol]}\f$
+     * \param XwNaCl mole fraction of NaCL in brine \f$\mathrm{[mol/mol]}\f$
      */
@@ -226,19 +226,19 @@ private:
      * \brief Returns the molality of NaCl \f$\mathrm{(mol NaCl / kg water)}\f$ for a given mole fraction
      *
-     * \param XlNaCl the XlNaCl \f$\mathrm{[kg NaCl / kg solution]}\f$
+     * \param XwNaCl the XwNaCl \f$\mathrm{[kg NaCl / kg solution]}\f$
      */
@@ -226,19 +226,19 @@ private:
 //        const Scalar Ms = 58.8e-3; /* molecular weight of NaCl  [kg/mol] */
 //
-//        const Scalar X_NaCl = XlNaCl;
-//        /* XlNaCl: conversion from mass fraction to mol fraction */
-//        const Scalar xlNaCl = -Mw * X_NaCl / ((Ms - Mw) * X_NaCl - Ms);
-//        return xlNaCl;
+//        const Scalar X_NaCl = XwNaCl;
+//        /* XwNaCl: conversion from mass fraction to mol fraction */
+//        const Scalar xwNaCl = -Mw * X_NaCl / ((Ms - Mw) * X_NaCl - Ms);
+//        return xwNaCl;
     }
 
-- 
GitLab